"""
WebSocket executor feature

This feature provides WebSocket communication capabilities for tasks.
Useful for bidirectional communication with WebSocket servers.
"""

from aipartnerupflow.extensions.websocket.websocket_executor import WebSocketExecutor

__all__ = ["WebSocketExecutor"]

