"""
gRPC executor feature

This feature provides gRPC service execution capabilities for tasks.
Useful for calling gRPC services and microservices.
"""

from aipartnerupflow.extensions.grpc.grpc_executor import GrpcExecutor

__all__ = ["GrpcExecutor"]

