"""
Base classes for aipartnerupflow

This module provides base class implementations that can be inherited
to get common functionality. All base classes implement core interfaces.
"""

from aipartnerupflow.core.base.base_task import BaseTask

__all__ = ["BaseTask"]

