"""
HTTP executor feature

This feature provides HTTP/REST API execution capabilities for tasks.
Useful for calling external REST APIs, webhooks, and HTTP-based services.
"""

from aipartnerupflow.extensions.http.rest_executor import RestExecutor

__all__ = ["RestExecutor"]

