"""
Generate Executor Extension

This extension provides a generate_executor that generates valid task tree
JSON arrays from natural language requirements using LLM.
"""

from aipartnerupflow.extensions.generate.generate_executor import GenerateExecutor

__all__ = ["GenerateExecutor"]

