"""
SSH executor feature

This feature provides SSH remote execution capabilities for tasks.
Useful for executing commands on remote servers via SSH.
"""

from aipartnerupflow.extensions.ssh.ssh_executor import SshExecutor

__all__ = ["SshExecutor"]

